# Duel

Team Name: Python Buds 
Team Members: Alexis Dougherty, Aaron Gonzales, Zach Stanford, Grace Wilcox, and Joshua Zimmerman
Github: https://github.com/AlexisDougherty13/Duel

## How to run:
The Duel game is a command line application, named duel.
Enter 'duel' into the command line to start the game


## PyPi Package Name
The PyPi Package Name is duel

## How to Play
### Objective
Maneuver your sword and position in order to avoid your opponent's attacks. Match your opponent's guard to deflect incoming strikes. Attack the opponent in the low, middle, or high guarding positions. If you strike when your opponent is unprepared, you will slay them!
### Controls
  * Player 1
    * A/D - Left/Right Movement
    * W/S - Guard Up/Down
    * Space - Jump
    * F - Sword Thrust
  * Player 2
    * Left/Right Arrow - Left/Right Movement
    * Up/Down Arrow - Guard Up/Down
    * Right Shift - Jump
    * Right Ctrl - Sword Thrust
